
## CATO-CLI - mutation.accountManagement.updateAccount:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.accountManagement.updateAccount) for documentation on this operation.

### Usage for mutation.accountManagement.updateAccount:

```bash
catocli mutation accountManagement updateAccount -h

catocli mutation accountManagement updateAccount <json>

catocli mutation accountManagement updateAccount --json-file mutation.accountManagement.updateAccount.json

catocli mutation accountManagement updateAccount '{"updateAccountInput":{"description":"string"}}'

catocli mutation accountManagement updateAccount '{
    "updateAccountInput": {
        "description": "string"
    }
}'
```

#### Operation Arguments for mutation.accountManagement.updateAccount ####

`accountId` [ID] - (required) N/A    
`updateAccountInput` [UpdateAccountInput] - (required) N/A    
